@@ -16,9 +16,10 @@ from ..logs import _logger
 from ..compat import VERSION
 from ..storage import TEMP_DIR
 
-from .tests_facade import SpintopAPIPersistenceFacade
+from .persistence_facade import SpintopAPIPersistenceFacade
 from .analytics import SpintopAPIAnalytics
 
+from spintop import __version__
 from spintop.utils.requests_utils import spintop_session
 
 logger = _logger('spintop-api')
@@ -103,7 +104,7 @@ class SpintopAPIClientModule(object):
         self.auth = auth
         
         self._selected_org_id = selected_org_id
-        self._tests_facade = SpintopAPIPersistenceFacade(self)
+        self._persistence_facade = SpintopAPIPersistenceFacade(self)
         self._analytics = SpintopAPIAnalytics(self)
         
         self._api_url = api_url
@@ -154,13 +155,17 @@ class SpintopAPIClientModule(object):
         return self._selected_org_id
 
     @property
-    def tests(self):
-        return self._tests_facade
+    def records(self):
+        return self._persistence_facade
 
     @property
     def analytics(self):
         return self._analytics
 
+    @property
+    def api_spintop_version(self):
+        return self.api_spec['versions']['spintop']
+
     def login(self):
         """Interactive login"""
         self.auth.assert_no_login() # Check first before prompting
@@ -203,20 +208,29 @@ class SpintopAPIClientModule(object):
     def create_org(self, org_id):
         return self.session.post(self.get_link('tenancy.create_org', org_id=org_id)).json()
 
-    def get_tests_env(self, org_id=None):
+    def get_records_env(self, org_id=None):
         """ An env that points to the API itself """
-        return self.session.get(self.get_link('tests.env', org_id=org_id)).json()
+        return self.session.get(self.get_link('records.env', org_id=org_id)).json()
 
-    def get_tests_env_direct_database_context(self, org_id=None):
+    def get_records_env_direct_database_context(self, org_id=None):
         """ An env that points to the API's underlying database (with the API's URI)"""
         if org_id is None: org_id = self.selected_org_id
-        env = self.get_tests_env(org_id)
+        env = self.get_records_env(org_id)
         org_info = self.get_org_info(org_id)
         return env.new_database_context(org_info['database_name'])
 
+    def _compare_api_version(self):
+        ours = __version__
+        apis = self.api_spintop_version
+        return f'API version: {apis!r}, ours: {ours!r}'
+
     def get_link(self, link_name, org_id=None, **kwargs):
         links = self.api_spec['_links']
-        base_link = links[link_name]
+        try:
+            base_link = links[link_name]
+        except KeyError:
+            # Link does not exist. Check API version.
+            raise KeyError(f'No link named {link_name!r} @ {self.api_url}. {self._compare_api_version()}. Availabe link names: {set(links.keys())}')
 
         if '<org_id>' in base_link:
             if org_id is None:
